package com.yanzhu.jh.project.mapper;

import java.util.List;
import com.yanzhu.jh.project.domain.SmzProjectQuarterlyAssess;

/**
 * 项目季度考核Mapper接口
 * 
 * @author ruoyi
 * @date 2023-08-05
 */
public interface SmzProjectQuarterlyAssessMapper 
{
    /**
     * 查询项目季度考核
     * 
     * @param id 项目季度考核主键
     * @return 项目季度考核
     */
    public SmzProjectQuarterlyAssess selectSmzProjectQuarterlyAssessById(Long id);

    /**
     * 查询项目季度考核列表
     * 
     * @param smzProjectQuarterlyAssess 项目季度考核
     * @return 项目季度考核集合
     */
    public List<SmzProjectQuarterlyAssess> selectSmzProjectQuarterlyAssessList(SmzProjectQuarterlyAssess smzProjectQuarterlyAssess);

    /**
     * 新增项目季度考核
     * 
     * @param smzProjectQuarterlyAssess 项目季度考核
     * @return 结果
     */
    public int insertSmzProjectQuarterlyAssess(SmzProjectQuarterlyAssess smzProjectQuarterlyAssess);

    /**
     * 修改项目季度考核
     * 
     * @param smzProjectQuarterlyAssess 项目季度考核
     * @return 结果
     */
    public int updateSmzProjectQuarterlyAssess(SmzProjectQuarterlyAssess smzProjectQuarterlyAssess);

    /**
     * 删除项目季度考核
     * 
     * @param id 项目季度考核主键
     * @return 结果
     */
    public int deleteSmzProjectQuarterlyAssessById(Long id);

    /**
     * 批量删除项目季度考核
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSmzProjectQuarterlyAssessByIds(Long[] ids);

    /**
     * 按部门获取当前季度考核目标
     * @param smzProjectQuarterlyAssess
     * @return
     */
    public List<SmzProjectQuarterlyAssess> currentListByDept(SmzProjectQuarterlyAssess smzProjectQuarterlyAssess);

    /**
     * 根据项目类型查询项目的季度计划
     * @param where
     * @return
     */
    public List<SmzProjectQuarterlyAssess> queryByProjectType(SmzProjectQuarterlyAssess where);
}
